import { swiftDataProperty, SwiftUICommon, BaseUIDataDriver } from './common';
import { Utils } from '@nativescript/core';
export * from './common';
const registry = new Map();
export function registerSwiftUI(id, callback) {
    registry.set(id, callback);
}
export class UIDataDriver extends BaseUIDataDriver {
    constructor(composeHolder, owner) {
        super(owner);
        this.composeHolder = composeHolder;
    }
    createNativeView() {
        const vc = this.composeHolder;
        return vc.view;
    }
    registerEvents(callback) {
        this.composeHolder.onEvent = (data) => {
            callback(data);
        };
    }
    updateData(data) {
        this.composeHolder.updateDataWithData(data);
    }
    onEvent(data) {
        const owner = this.owner.get();
        if (owner) {
            owner.notify({
                eventName: SwiftUICommon.swiftUIEventEvent,
                data: Utils.dataDeserialize(data),
            });
        }
    }
}
export class SwiftUI extends SwiftUICommon {
    createNativeView() {
        const generator = registry.get(this.swiftId);
        if (!generator) {
            console.warn('view not registered:', this.swiftId);
            return UIView.new();
        }
        this.swiftUIBridge = generator(this);
        return this.swiftUIBridge.createNativeView();
    }
    initNativeView() {
        if (!this.swiftUIBridge) {
            return;
        }
        this.swiftUIBridge.registerEvents((data) => {
            if (this.swiftUIBridge.onEvent) {
                this.swiftUIBridge.onEvent(data);
            }
            else {
                this.notify({
                    eventName: SwiftUI.swiftUIEventEvent,
                    data,
                });
            }
        });
    }
    disposeNativeView() {
        var _a, _b;
        super.disposeNativeView();
        if (this.swiftUIBridge) {
            (_b = (_a = this.swiftUIBridge).destroyNativeView) === null || _b === void 0 ? void 0 : _b.call(_a);
        }
    }
    [swiftDataProperty.setNative](data) {
        this.updateData(data);
    }
    updateData(data) {
        var _a, _b;
        (_b = (_a = this.swiftUIBridge) === null || _a === void 0 ? void 0 : _a.updateData) === null || _b === void 0 ? void 0 : _b.call(_a, data);
    }
}
//# sourceMappingURL=index.ios.js.map